<TS version="2.1" language="mk">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">Десен клик за уредување на адреса или етикета</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">Креирај нова адреса</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;Нова</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation type="unfinished">Копирај ја избраната адреса на системскиот клипборд</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">&amp;Копирај</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">З&amp;атвори</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">Избриши ја избраната адреса од листата</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Експортирај ги податоците од активното јазиче во датотека</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Експорт</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">&amp;Избриши</translation>
    </message>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Enter passphrase</source>
        <translation type="unfinished">Внеси тајна фраза</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation type="unfinished">Нова тајна фраза</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation type="unfinished">Повторете ја новата тајна фраза</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Сума</translation>
    </message>
    <message>
        <source>%1 d</source>
        <translation type="unfinished">%1 д</translation>
    </message>
    <message>
        <source>%1 h</source>
        <translation type="unfinished">%1 ч</translation>
    </message>
    <message>
        <source>%1 m</source>
        <translation type="unfinished">%1 м</translation>
    </message>
    <message>
        <source>%1 s</source>
        <translation type="unfinished">%1 с</translation>
    </message>
    <message>
        <source>%1 ms</source>
        <translation type="unfinished">%1 мс</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>%1 and %2</source>
        <translation type="unfinished">%1 и %2</translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>%1 B</source>
        <translation type="unfinished">%1 Б</translation>
    </message>
    <message>
        <source>%1 MB</source>
        <translation type="unfinished">%1 МБ</translation>
    </message>
    <message>
        <source>%1 GB</source>
        <translation type="unfinished">%1 ГБ</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Overview</source>
        <translation type="unfinished">&amp;Преглед</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation type="unfinished">&amp;Трансакции</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation type="unfinished">Преглед на историјата на трансакции</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished">И&amp;злез</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation type="unfinished">Напушти ја апликацијата</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation type="unfinished">За &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation type="unfinished">Прикажи информации за Qt</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation type="unfinished">Испрати биткоини на Биткоин адреса</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation type="unfinished">&amp;Испрати</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation type="unfinished">&amp;Прими</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation type="unfinished">Криптирај ги приватните клучеви кои припаѓаат на твојот паричник</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation type="unfinished">&amp;Подесувања</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;Помош</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation type="unfinished">%1 позади</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Грешка</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished">Предупредување</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation type="unfinished">Во тек</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;Прозорец</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation type="unfinished">Дата: %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation type="unfinished">Сума: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation type="unfinished">Тип: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation type="unfinished">Етикета: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation type="unfinished">Адреса: %1
</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Bytes:</source>
        <translation type="unfinished">Бајти:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Сума:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">Провизија:</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation type="unfinished">Прашина:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation type="unfinished">После Провизија:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation type="unfinished">Кусур:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Сума</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Дата</translation>
    </message>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Wallet</source>
        <translation type="unfinished">Паричник</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation type="unfinished">Измени Адреса</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation type="unfinished">&amp;Етикета</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation type="unfinished">&amp;Адреса</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>name</source>
        <translation type="unfinished">име</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Bitcoin</source>
        <translation type="unfinished">Биткоин</translation>
    </message>
    <message numerus="yes">
        <source>%n GB of space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Грешка</translation>
    </message>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation type="unfinished">верзија</translation>
    </message>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation type="unfinished">Опции</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation type="unfinished">&amp;Мрежа</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation type="unfinished">П&amp;аричник</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;Прозорец</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;ОК</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Откажи</translation>
    </message>
    <message>
        <source>none</source>
        <translation type="unfinished">нема</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Грешка</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Total:</source>
        <translation type="unfinished">Вкупно:</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Sent</source>
        <extracomment>Title of Peers Table column which indicates the total amount of network information we have sent to the peer.</extracomment>
        <translation type="unfinished">Испратени</translation>
    </message>
    <message>
        <source>Network</source>
        <extracomment>Title of Peers Table column which states the network the peer connected through.</extracomment>
        <translation type="unfinished">Мрежа</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Network</source>
        <translation type="unfinished">Мрежа</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished">Име</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation type="unfinished">Број на конекции</translation>
    </message>
    <message>
        <source>Sent</source>
        <translation type="unfinished">Испратени</translation>
    </message>
    <message>
        <source>Version</source>
        <translation type="unfinished">Верзија</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation type="unfinished">&amp;Конзола</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation type="unfinished">&amp;Сума:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;Етикета:</translation>
    </message>
    <message>
        <source>&amp;Message:</source>
        <translation type="unfinished">&amp;Порака:</translation>
    </message>
    <message>
        <source>Show</source>
        <translation type="unfinished">Прикажи</translation>
    </message>
    <message>
        <source>Copy &amp;URI</source>
        <translation type="unfinished">Копирај &amp;URI</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Сума:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation type="unfinished">Порака:</translation>
    </message>
    <message>
        <source>Copy &amp;URI</source>
        <translation type="unfinished">Копирај &amp;URI</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation type="unfinished">Копирај &amp;Адреса</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Дата</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Bytes:</source>
        <translation type="unfinished">Бајти:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Сума:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">Провизија:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation type="unfinished">После Провизија:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation type="unfinished">Кусур:</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation type="unfinished">Прашина:</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation type="unfinished">Сума:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;Етикета:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation type="unfinished">Порака:</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Дата</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Сума</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Дата</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Дата</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Error</source>
        <translation type="unfinished">Грешка</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Експорт</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Експортирај ги податоците од активното јазиче во датотека</translation>
    </message>
    </context>
</TS>